@@ -142,10 +142,15 @@ sub format_available {
         return;
     }
     
-    unless( $conf->get_program('make') ) { 
-        error( loc( "You do not have '%1' -- '%2' not available",
-                    'make', __PACKAGE__ ) ); 
-        return;
+    for my $pgm ( qw[make perlwrapper] ) {
+        unless( $conf->get_program( $pgm ) ) { 
+            error(loc(
+                "You do not have '%1' in your path -- '%2' not available\n" .
+                "Please check your config entry for '%1'", 
+                $pgm, __PACKAGE__ , $pgm
+            )); 
+            return;
+        }
     }
 
     return 1;     
@@ -277,7 +282,13 @@ sub prepare {
             ### make sure it's a string, so that mmflags that have more than
             ### one key value pair are passed as is, rather than as:
             ### perl Makefile.PL "key=val key=>val"
-            my $captured; my $makefile_pl = MAKEFILE_PL->();
+            my $captured; 
+            
+            #### XXX this needs to be the absolute path to the Makefile.PL
+            ### since cpanp-run-perl uses 'do' to execute the file, and do()
+            ### checks your @INC.. so, if there's _another_ makefile.pl in
+            ### your @INC, it will execute that one...
+            my $makefile_pl = MAKEFILE_PL->( $dir );
             
             ### setting autoflush to true fixes issue from rt #8047
             ### XXX this means that we need to keep the path to CPANPLUS
@@ -287,14 +298,18 @@ sub prepare {
             ### XXX this fails under ipc::run due to the extra quotes,
             ### but it works in ipc::open3. however, ipc::open3 doesn't work
             ### on win32/cygwin. XXX TODO get a windows box and sort this out
-#              my $cmd =  qq[$perl -MEnglish -le ] . 
-#                         QUOTE_PERL_ONE_LINER->(
-#                             qq[\$OUTPUT_AUTOFLUSH++,do(q($makefile_pl))]
-#                         ) 
-#                         . $mmflags;
+            # my $cmd =  qq[$perl -MEnglish -le ] . 
+            #            QUOTE_PERL_ONE_LINER->(
+            #                qq[\$OUTPUT_AUTOFLUSH++,do(q($makefile_pl))]
+            #            ) 
+            #            . $mmflags;
+
+            # my $flush = OPT_AUTOFLUSH;
+            # my $cmd     = "$perl $flush $makefile_pl $mmflags";
+
+            my $run_perl    = $conf->get_program('perlwrapper');
+            my $cmd         = "$perl $run_perl $makefile_pl $mmflags";
 
-            my $flush = OPT_AUTOFLUSH;
-            my $cmd     = "$perl $flush $makefile_pl $mmflags";
             unless( scalar run( command => $cmd,
                                 buffer  => \$captured,
                                 verbose => $run_verbose, # may be interactive   
@@ -652,6 +667,7 @@ Returns true on success, false on failure.
 =cut
 
 sub install {
+
     ### just in case you did the create with ANOTHER dist object linked
     ### to the same module object
     my $dist = shift();
@@ -664,8 +680,8 @@ sub install {
     
     
     unless( $dist->status->created ) {
-        error( loc( "You have not successfully created a '%2' distribution yet " .
-                    "-- cannot install yet", __PACKAGE__ ) );
+        error(loc("You have not successfully created a '%2' distribution yet " .
+                  "-- cannot install yet", __PACKAGE__ ));
         return;
     }
  
@@ -718,7 +734,8 @@ sub install {
     my $cmd     = [$make, 'install', $makeflags];
     my $sudo    = $conf->get_program('sudo');
     unshift @$cmd, $sudo if $sudo and $>;
-    
+
+    $cb->flush('lib');
     unless(scalar run(  command => $cmd,
                         verbose => $verbose,
                         buffer  => \$captured,
